@@ -6,6 +6,12 @@ set -e
 UPSTREAM_VERSION="$(dpkg-parsechangelog | grep '^Version:' | sed -e 's,^Version: ,,' -e 's,\.\(dfsg\|original\),,' -e 's,-[0-9\.]*[~\+]\(.*\),,')"
 UPSTREAM_MAJOR="$(echo ${UPSTREAM_VERSION} | cut -d . -f 1,2)"
 
+if [ "$1" = "https" ]; then
+        sed -e "s#git://#https://#" \
+                < .gitmodules > .gitmodules.new && \
+                mv .gitmodules.new .gitmodules
+fi
+
 git submodule --quiet update --init
 if [ -d syslog-ng-${UPSTREAM_MAJOR} ]; then
         (cd syslog-ng-${UPSTREAM_MAJOR} && git submodule --quiet sync)
